@@ -3,7 +3,7 @@
 ##########################################################################
 # OpenLP - Open Source Lyrics Projection                                 #
 # ---------------------------------------------------------------------- #
-# Copyright (c) 2008-2022 OpenLP Developers                              #
+# Copyright (c) 2008-2023 OpenLP Developers                              #
 # ---------------------------------------------------------------------- #
 # This program is free software: you can redistribute it and/or modify   #
 # it under the terms of the GNU General Public License as published by   #
@@ -22,6 +22,7 @@
 The :mod:`languages` module provides a list of language names with utility functions.
 """
 import itertools
+import locale
 import logging
 import re
 from collections import namedtuple
@@ -51,7 +52,8 @@ def translate(context, text, comment=None, qt_translate=QtCore.QCoreApplication.
 
 
 Language = namedtuple('Language', ['id', 'name', 'code'])
-COLLATOR = None
+ICU_COLLATOR = None
+DIGITS_OR_NONDIGITS = re.compile(r'\d+|\D+')
 LANGUAGES = sorted([
     Language(1, translate('common.languages', '(Afan) Oromo', 'Language code: om'), 'om'),
     Language(2, translate('common.languages', 'Abkhazian', 'Language code: ab'), 'ab'),
@@ -503,19 +505,25 @@ def format_time(text, local_time):
     return re.sub(r'%[a-zA-Z]', match_formatting, text)
 
 
-def get_locale_key(string, numeric=False):
+def get_locale_key(string):
     """
     Creates a key for case insensitive, locale aware string sorting.
 
     :param string: The corresponding string.
     """
     string = string.lower()
-    global COLLATOR
-    if COLLATOR is None:
-        language = LanguageManager.get_language()
-        COLLATOR = QtCore.QCollator(QtCore.QLocale(language))
-    COLLATOR.setNumericMode(numeric)
-    return COLLATOR.sortKey(string)
+    # ICU is the prefered way to handle locale sort key, we fallback to locale.strxfrm which will work in most cases.
+    global ICU_COLLATOR
+    try:
+        if ICU_COLLATOR is None:
+            import icu
+            language = LanguageManager.get_language()
+            icu_locale = icu.Locale(language)
+            ICU_COLLATOR = icu.Collator.createInstance(icu_locale)
+        return ICU_COLLATOR.getSortKey(string)
+    except Exception:
+        log.warning('ICU not found! Fallback to strxfrm')
+        return locale.strxfrm(string).encode()
 
 
 def get_natural_key(string):
@@ -525,7 +533,13 @@ def get_natural_key(string):
     :param string: string to be sorted by
     Returns a list of string compare keys and integers.
     """
-    return get_locale_key(string, True)
+    key = DIGITS_OR_NONDIGITS.findall(string)
+    key = [int(part) if part.isdigit() else get_locale_key(part) for part in key]
+    # Python 3 does not support comparison of different types anymore. So make sure, that we do not compare str
+    # and int.
+    if string and string[0].isdigit():
+        return [b''] + key
+    return key
 
 
 def get_language(name):
