@@ -3,7 +3,7 @@
 ##########################################################################
 # OpenLP - Open Source Lyrics Projection                                 #
 # ---------------------------------------------------------------------- #
-# Copyright (c) 2008-2022 OpenLP Developers                              #
+# Copyright (c) 2008-2023 OpenLP Developers                              #
 # ---------------------------------------------------------------------- #
 # This program is free software: you can redistribute it and/or modify   #
 # it under the terms of the GNU General Public License as published by   #
@@ -815,7 +815,8 @@ class ThemePreviewRenderer(DisplayWindow, LogMixin):
             check_string = separator.join(html_list[index + 1:]).strip()
             if self._text_fits_on_slide(html_tags + check_string):
                 previous_html = html_tags + check_string + line_end
-                previous_raw = raw_tags + check_string + line_end
+                check_string_raw = separator.join(raw_list[index + 1:]).strip()
+                previous_raw = raw_tags + check_string_raw + line_end
                 break
             else:
                 # The remaining elements do not fit, thus reset the indexes, create a new list and continue.
