@@ -3,7 +3,7 @@
 ##########################################################################
 # OpenLP - Open Source Lyrics Projection                                 #
 # ---------------------------------------------------------------------- #
-# Copyright (c) 2008-2022 OpenLP Developers                              #
+# Copyright (c) 2008-2023 OpenLP Developers                              #
 # ---------------------------------------------------------------------- #
 # This program is free software: you can redistribute it and/or modify   #
 # it under the terms of the GNU General Public License as published by   #
@@ -348,8 +348,9 @@ class SongImportForm(OpenLPWizard, RegistryProperties):
 
         :rtype: None
         """
-        file_path, filter_used = FileDialog.getSaveFileName(
-            self, self.settings.value('songs/last directory import'))
+        file_path, filter_used = FileDialog.getSaveFileName(self,
+                                                            translate('SongPlugin.SongImporter', 'Save Error File'),
+                                                            self.settings.value('songs/last directory import'))
         if file_path is None:
             return
         file_path.write_text(self.error_report_text_edit.toPlainText(), encoding='utf-8')
